@@ -311,7 +311,7 @@ class Stock:
         if sectors:
             for sector in sectors:
                 googlenews = GoogleNews(lang='en', period='14d')
-                googlenews.get_news(sector)
+                googlenews.get_news(sector} sector stocks')
                 sector_news.append(googlenews.result())
     
         return df, news, press_releases, sector_news, stock_news
@@ -422,9 +422,7 @@ class Stock:
         data = self.get_month_data()
         adl = 0.0
         for row in data.iterrows():
-            adl += (((row['Close'] - row['Low']) - (['High'] - row['Close']))/(['High'] - row['Low'])) * row['Volume']
-            print(adl)
-        
+            adl += (((row['Close'] - row['Low']) - (['High'] - row['Close']))/(['High'] - row['Low'])) * row['Volume']     
         
         return adl
   
